@@ -1,6 +1,52 @@
 from django.db import models
 
 
+class TrainingRun(models.Model):
+  """Represents a full training run by Masterful.
+  
+  This model mirros the TrainingRun proto. All details are in proto definition.
+  """
+  # The name of the run.
+  name = models.CharField(primary_key=True, max_length=250)
+
+  # Datetime of when the training run was completed. We call it 'ts' to match
+  # the proto name for ease of conversions, even though it's a datetime
+  # field and not a timestamp.
+  completed_ts = models.DateTimeField()
+
+  # Information about the model. This is a Model proto json representation.
+  model_info = models.JSONField(default=dict)
+
+  # Results of searching for optimal policy and training with it. This is a
+  # PolicySearchTask proto json representation.
+  policy_search_results = models.JSONField(default=dict)
+
+  # Name of the approach which performed the run.
+  approach_name = models.CharField(max_length=120)
+
+  # Version of the masterful pip package which produced the run.
+  masterful_version = models.CharField(default="", max_length=100)
+
+  # The CV task the run was used for.
+  task = models.CharField(default="", max_length=100)
+
+  # The absolute path of the model graph image on disk.
+  model_graph_image = models.CharField(default="", max_length=100)
+
+  # Optimization params used in training.
+  optimization_params = models.JSONField(default=dict)
+
+  # SSL params used in training.
+  ssl_params = models.JSONField(default=dict)
+
+  # Datasets used in this training run. Can also include evaluation (test) set
+  # when CLI is used for the run.
+  datasets = models.JSONField(default=dict)
+
+
+############
+# DEPRECATED
+############
 class PolicySearchTask(models.Model):
   """The main PolicySearchTask model.
   
