@@ -14,4 +14,11 @@ class DatasetModelSerializer(serializers.ModelSerializer):
 
   class Meta:
     model = models.Dataset
+    fields = '__all__'
+
+
+class TrainingRunModelSerializer(serializers.ModelSerializer):
+
+  class Meta:
+    model = models.TrainingRun
     fields = '__all__'
\ No newline at end of file
