@@ -19,12 +19,15 @@ from django.views.generic import TemplateView
 from rest_framework import routers
 from django.contrib.staticfiles.storage import staticfiles_storage
 from django.views.generic.base import RedirectView
+from django.conf import settings
+from django.conf.urls.static import static
 
 from masterful_gui.backend.apps.api import views
 
 router = routers.DefaultRouter()
 router.register(r'search', views.PolicySearchTaskView, 'search')
 router.register(r'dataset', views.DatasetView, 'dataset')
+router.register(r'trainingrun', views.TrainingRunView, 'trainingrun')
 
 urlpatterns = [
     path('admin/', admin.site.urls),
@@ -33,4 +36,4 @@ urlpatterns = [
     path('', TemplateView.as_view(template_name="index.html")),
     path('favicon.ico',
          RedirectView.as_view(url=staticfiles_storage.url('img/favicon.ico'))),
-]
+] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
