@@ -17,10 +17,12 @@ _DEFAULT_PORT = 7007
 # The name assigned to the server instance.
 _SERVER_NAME = "Masterful GUI"
 
-# TODO(ray): If the user picks a different port, CORS problems might be
-# introduced. Add a dynamic solution to whitelist the user selected port
-# to prevent CORS breakages.
-flags.DEFINE_integer('port', _DEFAULT_PORT, 'The port for running the server')
+# TODO(ray): Add dynamic support across the app for using a variable port value.
+# This includes CORS configurations as well as media storage URL generation.
+# For now we are keeping this flag disabled untill we implement this support
+# to avoid having the app break if users select a different port than the
+# default one.
+# flags.DEFINE_integer('port', _DEFAULT_PORT, 'The port for running the server')
 
 
 def run_main():
